/* User code */
import java.io.*;   // For FileInputStream and its exceptions.
/*
=========================================================================
*/
class Token {
  public int type;
  public Range range;
  public String spelling;
  static int lastline = 0;
  public Token(int t, int l, int c, int r, String s)
    {
      type = t;
      Location first = new Location(c, l, c-lastline);
      Location last = new Location(r, l, r-lastline);
      range = new Range(first, last);
      spelling = s;
    }
/* ------------------------------------------------------------------------- */
  public static final int AND       = 0; // Reserved words
  public static final int BEGIN     = 1;
  public static final int CALL      = 2;
  public static final int DO        = 3;
  public static final int ELSE      = 4;
  public static final int END       = 5;
  public static final int IF        = 6;
  public static final int NOT       = 7;
  public static final int OR        = 8;
  public static final int PROC      = 9;
  public static final int PROGRAM   = 10; 
  public static final int SKIP      = 11;
  public static final int THEN      = 12;
  public static final int WHILE     = 13;
  public static final int BOOL      = 14;  // Boolean literal (true or false)
  public static final int NUM       = 15;  // Integer literal
  public static final int ID        = 16;  // Identifier
  public static final int SEMICOLON = 17;  // Separators
  public static final int LPAREN    = 18;
  public static final int RPAREN    = 19;
  public static final int ASSIGN    = 20;  //assignment
  public static final int PLUS      = 21;  // arithmetic operators
  public static final int MINUS     = 22;
  public static final int TIMES     = 23;
  public static final int DIV       = 24;
  public static final int EQ        = 25;  // relational operators
  public static final int NOTEQ     = 26; 
  public static final int GT        = 27;
  public static final int GTEQ      = 28;
  public static final int LT        = 29;
  public static final int LTEQ      = 30;
  public static final int EOF       = 31;  // end of file
  public static final int ERROR     = 32;  // lexical error
  // These are for the Parser's error messages.
  public static final String[] spellingOf =
    {
    "and",
    "begin",
    "call",
    "do",
    "else",
    "end",
    "if",
    "not",
    "or",
    "proc",
    "program",
    "skip",
    "then",
    "while",
    "boolean-literal",
    "integer-literal",
    "identifier",
    ";",
    "(",
    ")",
    ":=",
    "+",
    "-",
    "*",
    "/",
    "=",
    "<>",
    ">",
    ">=",
    "<",
    "<=",
    "end of file",
    "*err*"
    };
  public static String spellingOf(int t) { return spellingOf[t]; }
  public String toString()
    {
    if ( type == ID || type == BOOL || type == NUM )
      return "\"" + spelling + "\"  " + range;
    else
      return spelling + " " + range;
    }
};
/*
=========================================================================
*/


class Lexer {
	private final int YY_BUFFER_SIZE = 512;
	private final int YY_F = -1;
	private final int YY_NO_STATE = -1;
	private final int YY_NOT_ACCEPT = 0;
	private final int YY_START = 1;
	private final int YY_END = 2;
	private final int YY_NO_ANCHOR = 4;
	private final int YY_BOL = 128;
	private final int YY_EOF = 129;
	private java.io.BufferedReader yy_reader;
	private int yy_buffer_index;
	private int yy_buffer_read;
	private int yy_buffer_start;
	private int yy_buffer_end;
	private char yy_buffer[];
	private int yychar;
	private int yyline;
	private boolean yy_at_bol;
	private int yy_lexical_state;

	Lexer (java.io.Reader reader) {
		this ();
		if (null == reader) {
			throw (new Error("Error: Bad input stream initializer."));
		}
		yy_reader = new java.io.BufferedReader(reader);
	}

	Lexer (java.io.InputStream instream) {
		this ();
		if (null == instream) {
			throw (new Error("Error: Bad input stream initializer."));
		}
		yy_reader = new java.io.BufferedReader(new java.io.InputStreamReader(instream));
	}

	private Lexer () {
		yy_buffer = new char[YY_BUFFER_SIZE];
		yy_buffer_read = 0;
		yy_buffer_index = 0;
		yy_buffer_start = 0;
		yy_buffer_end = 0;
		yychar = 0;
		yyline = 0;
		yy_at_bol = true;
		yy_lexical_state = YYINITIAL;
	}

	private boolean yy_eof_done = false;
	private final int YYINITIAL = 0;
	private final int yy_state_dtrans[] = {
		0
	};
	private void yybegin (int state) {
		yy_lexical_state = state;
	}
	private int yy_advance ()
		throws java.io.IOException {
		int next_read;
		int i;
		int j;

		if (yy_buffer_index < yy_buffer_read) {
			return yy_buffer[yy_buffer_index++];
		}

		if (0 != yy_buffer_start) {
			i = yy_buffer_start;
			j = 0;
			while (i < yy_buffer_read) {
				yy_buffer[j] = yy_buffer[i];
				++i;
				++j;
			}
			yy_buffer_end = yy_buffer_end - yy_buffer_start;
			yy_buffer_start = 0;
			yy_buffer_read = j;
			yy_buffer_index = j;
			next_read = yy_reader.read(yy_buffer,
					yy_buffer_read,
					yy_buffer.length - yy_buffer_read);
			if (-1 == next_read) {
				return YY_EOF;
			}
			yy_buffer_read = yy_buffer_read + next_read;
		}

		while (yy_buffer_index >= yy_buffer_read) {
			if (yy_buffer_index >= yy_buffer.length) {
				yy_buffer = yy_double(yy_buffer);
			}
			next_read = yy_reader.read(yy_buffer,
					yy_buffer_read,
					yy_buffer.length - yy_buffer_read);
			if (-1 == next_read) {
				return YY_EOF;
			}
			yy_buffer_read = yy_buffer_read + next_read;
		}
		return yy_buffer[yy_buffer_index++];
	}
	private void yy_move_end () {
		if (yy_buffer_end > yy_buffer_start &&
		    '\n' == yy_buffer[yy_buffer_end-1])
			yy_buffer_end--;
		if (yy_buffer_end > yy_buffer_start &&
		    '\r' == yy_buffer[yy_buffer_end-1])
			yy_buffer_end--;
	}
	private boolean yy_last_was_cr=false;
	private void yy_mark_start () {
		int i;
		for (i = yy_buffer_start; i < yy_buffer_index; ++i) {
			if ('\n' == yy_buffer[i] && !yy_last_was_cr) {
				++yyline;
			}
			if ('\r' == yy_buffer[i]) {
				++yyline;
				yy_last_was_cr=true;
			} else yy_last_was_cr=false;
		}
		yychar = yychar
			+ yy_buffer_index - yy_buffer_start;
		yy_buffer_start = yy_buffer_index;
	}
	private void yy_mark_end () {
		yy_buffer_end = yy_buffer_index;
	}
	private void yy_to_mark () {
		yy_buffer_index = yy_buffer_end;
		yy_at_bol = (yy_buffer_end > yy_buffer_start) &&
		            ('\r' == yy_buffer[yy_buffer_end-1] ||
		             '\n' == yy_buffer[yy_buffer_end-1] ||
		             2028/*LS*/ == yy_buffer[yy_buffer_end-1] ||
		             2029/*PS*/ == yy_buffer[yy_buffer_end-1]);
	}
	private java.lang.String yytext () {
		return (new java.lang.String(yy_buffer,
			yy_buffer_start,
			yy_buffer_end - yy_buffer_start));
	}
	private int yylength () {
		return yy_buffer_end - yy_buffer_start;
	}
	private char[] yy_double (char buf[]) {
		int i;
		char newbuf[];
		newbuf = new char[2*buf.length];
		for (i = 0; i < buf.length; ++i) {
			newbuf[i] = buf[i];
		}
		return newbuf;
	}
	private final int YY_E_INTERNAL = 0;
	private final int YY_E_MATCH = 1;
	private java.lang.String yy_error_string[] = {
		"Error: Internal error.\n",
		"Error: Unmatched input.\n"
	};
	private void yy_error (int code,boolean fatal) {
		java.lang.System.out.print(yy_error_string[code]);
		java.lang.System.out.flush();
		if (fatal) {
			throw new Error("Fatal Error.\n");
		}
	}
	private int[][] unpackFromString(int size1, int size2, String st) {
		int colonIndex = -1;
		String lengthString;
		int sequenceLength = 0;
		int sequenceInteger = 0;

		int commaIndex;
		String workString;

		int res[][] = new int[size1][size2];
		for (int i= 0; i < size1; i++) {
			for (int j= 0; j < size2; j++) {
				if (sequenceLength != 0) {
					res[i][j] = sequenceInteger;
					sequenceLength--;
					continue;
				}
				commaIndex = st.indexOf(',');
				workString = (commaIndex==-1) ? st :
					st.substring(0, commaIndex);
				st = st.substring(commaIndex+1);
				colonIndex = workString.indexOf(':');
				if (colonIndex == -1) {
					res[i][j]=Integer.parseInt(workString);
					continue;
				}
				lengthString =
					workString.substring(colonIndex+1);
				sequenceLength=Integer.parseInt(lengthString);
				workString=workString.substring(0,colonIndex);
				sequenceInteger=Integer.parseInt(workString);
				res[i][j] = sequenceInteger;
				sequenceLength--;
			}
		}
		return res;
	}
	private int yy_acpt[] = {
		/* 0 */ YY_NOT_ACCEPT,
		/* 1 */ YY_NO_ANCHOR,
		/* 2 */ YY_NO_ANCHOR,
		/* 3 */ YY_NO_ANCHOR,
		/* 4 */ YY_NO_ANCHOR,
		/* 5 */ YY_NO_ANCHOR,
		/* 6 */ YY_NO_ANCHOR,
		/* 7 */ YY_NO_ANCHOR,
		/* 8 */ YY_NO_ANCHOR,
		/* 9 */ YY_NO_ANCHOR,
		/* 10 */ YY_NO_ANCHOR,
		/* 11 */ YY_NO_ANCHOR,
		/* 12 */ YY_NO_ANCHOR,
		/* 13 */ YY_NO_ANCHOR,
		/* 14 */ YY_NO_ANCHOR,
		/* 15 */ YY_NO_ANCHOR,
		/* 16 */ YY_NO_ANCHOR,
		/* 17 */ YY_NO_ANCHOR,
		/* 18 */ YY_NO_ANCHOR,
		/* 19 */ YY_NO_ANCHOR,
		/* 20 */ YY_NO_ANCHOR,
		/* 21 */ YY_NO_ANCHOR,
		/* 22 */ YY_NO_ANCHOR,
		/* 23 */ YY_NO_ANCHOR,
		/* 24 */ YY_NO_ANCHOR,
		/* 25 */ YY_NO_ANCHOR,
		/* 26 */ YY_NO_ANCHOR,
		/* 27 */ YY_NO_ANCHOR,
		/* 28 */ YY_NO_ANCHOR,
		/* 29 */ YY_NO_ANCHOR,
		/* 30 */ YY_NO_ANCHOR,
		/* 31 */ YY_NO_ANCHOR,
		/* 32 */ YY_NO_ANCHOR,
		/* 33 */ YY_NO_ANCHOR,
		/* 34 */ YY_NO_ANCHOR,
		/* 35 */ YY_NO_ANCHOR,
		/* 36 */ YY_NO_ANCHOR,
		/* 37 */ YY_NO_ANCHOR,
		/* 38 */ YY_NOT_ACCEPT,
		/* 39 */ YY_NO_ANCHOR,
		/* 40 */ YY_NO_ANCHOR,
		/* 41 */ YY_NO_ANCHOR,
		/* 42 */ YY_NO_ANCHOR,
		/* 43 */ YY_NO_ANCHOR,
		/* 44 */ YY_NOT_ACCEPT,
		/* 45 */ YY_NO_ANCHOR,
		/* 46 */ YY_NOT_ACCEPT,
		/* 47 */ YY_NO_ANCHOR,
		/* 48 */ YY_NO_ANCHOR,
		/* 49 */ YY_NO_ANCHOR,
		/* 50 */ YY_NO_ANCHOR,
		/* 51 */ YY_NO_ANCHOR,
		/* 52 */ YY_NO_ANCHOR,
		/* 53 */ YY_NO_ANCHOR,
		/* 54 */ YY_NO_ANCHOR,
		/* 55 */ YY_NO_ANCHOR,
		/* 56 */ YY_NO_ANCHOR,
		/* 57 */ YY_NO_ANCHOR,
		/* 58 */ YY_NO_ANCHOR,
		/* 59 */ YY_NO_ANCHOR,
		/* 60 */ YY_NO_ANCHOR,
		/* 61 */ YY_NO_ANCHOR,
		/* 62 */ YY_NO_ANCHOR,
		/* 63 */ YY_NO_ANCHOR,
		/* 64 */ YY_NO_ANCHOR,
		/* 65 */ YY_NO_ANCHOR,
		/* 66 */ YY_NO_ANCHOR,
		/* 67 */ YY_NO_ANCHOR,
		/* 68 */ YY_NO_ANCHOR,
		/* 69 */ YY_NO_ANCHOR,
		/* 70 */ YY_NO_ANCHOR,
		/* 71 */ YY_NO_ANCHOR,
		/* 72 */ YY_NO_ANCHOR,
		/* 73 */ YY_NO_ANCHOR,
		/* 74 */ YY_NO_ANCHOR,
		/* 75 */ YY_NO_ANCHOR,
		/* 76 */ YY_NO_ANCHOR,
		/* 77 */ YY_NO_ANCHOR,
		/* 78 */ YY_NO_ANCHOR,
		/* 79 */ YY_NO_ANCHOR,
		/* 80 */ YY_NO_ANCHOR,
		/* 81 */ YY_NO_ANCHOR,
		/* 82 */ YY_NO_ANCHOR,
		/* 83 */ YY_NO_ANCHOR,
		/* 84 */ YY_NO_ANCHOR,
		/* 85 */ YY_NO_ANCHOR
	};
	private int yy_cmap[] = unpackFromString(1,130,
"6:8,3:2,2,6,3,1,6:18,3,6:7,31,32,5,35,6,36,6,4,27,28:9,33,30,37,34,38,6:2,2" +
"9:26,6:6,11,13,18,17,14,21,10,23,15,29,20,24,12,16,9,7,29,8,19,22,26,29,25," +
"29:3,6:5,0:2")[0];

	private int yy_rmap[] = unpackFromString(1,86,
"0,1,2,1,3,1:2,4,1:7,5,6,7,8:3,1:4,8:13,9,1,10,11,12,1,13,14,15,16,17,18,19," +
"20,21,22,23,24,25,26,27,28,29,30,31,32,33,8,34,35,36,37,38,39,40,41,42,43,4" +
"4,45,46,8,47,48,49,50,51,52")[0];

	private int yy_nxt[][] = unpackFromString(53,39,
"1,2,39,3,4,5,6,7,79,41,79,61,79,80,62,45,63,47,81,82,79,83,84,79:2,85,79,8," +
"42,79,9,10,11,40,12,13,14,15,16,-1:41,39,-1:40,17,38,-1:40,79,64,79:18,65:2" +
",79,-1:43,22,-1:3,23,-1:34,24,-1:7,17:36,-1:7,79:20,65:2,79,-1:10,38:4,44,3" +
"8:33,-1:34,21,-1:11,79,18,79:18,65:2,79,-1:36,42:2,-1:11,46:3,43,44,46:33,-" +
"1:7,79:14,19,79:5,65:2,79,-1:10,46:4,44,46:33,-1:7,79:2,20,79:17,65:2,79,-1" +
":16,79:10,25,79:9,65:2,79,-1:16,79:10,26,79:9,65:2,79,-1:16,79:15,27,79:4,6" +
"5:2,79,-1:16,79:3,77,79:7,28,79:8,65:2,79,-1:16,79:7,29,79:12,65:2,79,-1:16" +
",79:17,30,79:2,65:2,79,-1:16,31,79:19,65:2,79,-1:16,79:7,32,79:12,65:2,79,-" +
"1:16,79:9,33,79:10,65:2,79,-1:16,79:9,34,79:10,65:2,79,-1:16,79:7,35,79:12," +
"65:2,79,-1:16,79:7,36,79:12,65:2,79,-1:16,79:5,37,79:14,65:2,79,-1:16,79:9," +
"48,79:10,65:2,79,-1:16,79:9,49,79:7,67,79:2,65:2,79,-1:16,79:2,50,79:17,65:" +
"2,79,-1:16,79:2,51,79:17,65:2,79,-1:16,79:3,74,79:16,65:2,79,-1:16,79:12,52" +
",79:7,65:2,79,-1:16,79:17,53,79:2,65:2,79,-1:16,79:8,54,79:11,65:2,79,-1:16" +
",79:17,75,79:2,65:2,79,-1:16,79:19,55,65:2,79,-1:16,79:7,56,79:12,65:2,79,-" +
"1:16,79:8,76,79:11,65:2,79,-1:16,79:8,57,79:11,65:2,79,-1:16,79:12,58,79:7," +
"65:2,79,-1:16,79:17,59,79:2,65:2,79,-1:16,79,78,79:18,65:2,79,-1:16,79:4,60" +
",79:15,65:2,79,-1:16,79:7,66,79:12,65:2,79,-1:16,79:4,68,79:15,65:2,79,-1:1" +
"6,79:13,69,79:6,65:2,79,-1:16,79:4,70,79:15,65:2,79,-1:16,79,71,79:14,72,79" +
":3,65:2,79,-1:16,79:16,73,79:3,65:2,79,-1:9");

	public Token next ()
		throws java.io.IOException {
		int yy_lookahead;
		int yy_anchor = YY_NO_ANCHOR;
		int yy_state = yy_state_dtrans[yy_lexical_state];
		int yy_next_state = YY_NO_STATE;
		int yy_last_accept_state = YY_NO_STATE;
		boolean yy_initial = true;
		int yy_this_accept;

		yy_mark_start();
		yy_this_accept = yy_acpt[yy_state];
		if (YY_NOT_ACCEPT != yy_this_accept) {
			yy_last_accept_state = yy_state;
			yy_mark_end();
		}
		while (true) {
			if (yy_initial && yy_at_bol) yy_lookahead = YY_BOL;
			else yy_lookahead = yy_advance();
			yy_next_state = YY_F;
			yy_next_state = yy_nxt[yy_rmap[yy_state]][yy_cmap[yy_lookahead]];
			if (YY_EOF == yy_lookahead && true == yy_initial) {
 
  return new Token(Token.EOF, yyline, yychar, yychar, Token.spellingOf(Token.EOF));
			}
			if (YY_F != yy_next_state) {
				yy_state = yy_next_state;
				yy_initial = false;
				yy_this_accept = yy_acpt[yy_state];
				if (YY_NOT_ACCEPT != yy_this_accept) {
					yy_last_accept_state = yy_state;
					yy_mark_end();
				}
			}
			else {
				if (YY_NO_STATE == yy_last_accept_state) {
					throw (new Error("Lexical Error: Unmatched Input."));
				}
				else {
					yy_anchor = yy_acpt[yy_last_accept_state];
					if (0 != (YY_END & yy_anchor)) {
						yy_move_end();
					}
					yy_to_mark();
					switch (yy_last_accept_state) {
					case 1:
						
					case -2:
						break;
					case 2:
						{ Token.lastline = yychar+1; }
					case -3:
						break;
					case 3:
						{}
					case -4:
						break;
					case 4:
						{ return new Token(Token.DIV, yyline, yychar, yychar, yytext()); }
					case -5:
						break;
					case 5:
						{ return new Token(Token.TIMES, yyline, yychar, yychar, yytext()); }
					case -6:
						break;
					case 6:
						{ return new Token(Token.ERROR, yyline, yychar, yychar, yytext()); }
					case -7:
						break;
					case 7:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -8:
						break;
					case 8:
						{ return new Token(Token.NUM, yyline,
                            yychar, yychar+yytext().length()-1,
                             yytext() ); }
					case -9:
						break;
					case 9:
						{ return new Token(Token.SEMICOLON, yyline, yychar, yychar, yytext()); }
					case -10:
						break;
					case 10:
						{ return new Token(Token.LPAREN, yyline, yychar, yychar, yytext()); }
					case -11:
						break;
					case 11:
						{ return new Token(Token.RPAREN, yyline, yychar, yychar, yytext()); }
					case -12:
						break;
					case 12:
						{ return new Token(Token.EQ, yyline, yychar, yychar, yytext()); }
					case -13:
						break;
					case 13:
						{ return new Token(Token.PLUS, yyline, yychar, yychar, yytext()); }
					case -14:
						break;
					case 14:
						{ return new Token(Token.MINUS, yyline, yychar, yychar, yytext()); }
					case -15:
						break;
					case 15:
						{ return new Token(Token.LT, yyline, yychar, yychar, yytext()); }
					case -16:
						break;
					case 16:
						{ return new Token(Token.GT, yyline, yychar, yychar, yytext()); }
					case -17:
						break;
					case 17:
						{}
					case -18:
						break;
					case 18:
						{ return new Token(Token.OR, yyline, yychar, yychar+1, yytext()); }
					case -19:
						break;
					case 19:
						{ return new Token(Token.IF, yyline, yychar, yychar+1, yytext()); }
					case -20:
						break;
					case 20:
						{ return new Token(Token.DO, yyline, yychar, yychar+1, yytext()); }
					case -21:
						break;
					case 21:
						{ return new Token(Token.ASSIGN, yyline, yychar, yychar, yytext()); }
					case -22:
						break;
					case 22:
						{ return new Token(Token.LTEQ, yyline, yychar, yychar+1, yytext()); }
					case -23:
						break;
					case 23:
						{ return new Token(Token.NOTEQ, yyline, yychar, yychar+1, yytext()); }
					case -24:
						break;
					case 24:
						{ return new Token(Token.GTEQ, yyline, yychar, yychar+1, yytext()); }
					case -25:
						break;
					case 25:
						{ return new Token(Token.AND, yyline, yychar, yychar+2, yytext()); }
					case -26:
						break;
					case 26:
						{ return new Token(Token.END, yyline, yychar, yychar+2, yytext()); }
					case -27:
						break;
					case 27:
						{ return new Token(Token.NOT, yyline, yychar, yychar+2, yytext()); }
					case -28:
						break;
					case 28:
						{ return new Token(Token.PROC, yyline, yychar, yychar+3, yytext()); }
					case -29:
						break;
					case 29:
						{ return new Token(Token.ELSE, yyline, yychar, yychar+3, yytext()); }
					case -30:
						break;
					case 30:
						{ return new Token(Token.CALL, yyline, yychar, yychar+3, yytext()); }
					case -31:
						break;
					case 31:
						{ return new Token(Token.SKIP, yyline, yychar, yychar+3, yytext()); }
					case -32:
						break;
					case 32:
						{ return new Token(Token.BOOL, yyline, yychar, 
                   yychar+3, yytext()); }
					case -33:
						break;
					case 33:
						{ return new Token(Token.THEN, yyline, yychar, yychar+3, yytext()); }
					case -34:
						break;
					case 34:
						{ return new Token(Token.BEGIN, yyline, yychar, yychar+4, yytext()); }
					case -35:
						break;
					case 35:
						{ return new Token(Token.BOOL, yyline, yychar, 
                   yychar+4, yytext()); }
					case -36:
						break;
					case 36:
						{ return new Token(Token.WHILE, yyline, yychar, yychar+4, yytext()); }
					case -37:
						break;
					case 37:
						{ return new Token(Token.PROGRAM, yyline, yychar, yychar+6, yytext()); }
					case -38:
						break;
					case 39:
						{ Token.lastline = yychar+1; }
					case -39:
						break;
					case 40:
						{ return new Token(Token.ERROR, yyline, yychar, yychar, yytext()); }
					case -40:
						break;
					case 41:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -41:
						break;
					case 42:
						{ return new Token(Token.NUM, yyline,
                            yychar, yychar+yytext().length()-1,
                             yytext() ); }
					case -42:
						break;
					case 43:
						{}
					case -43:
						break;
					case 45:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -44:
						break;
					case 47:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -45:
						break;
					case 48:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -46:
						break;
					case 49:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -47:
						break;
					case 50:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -48:
						break;
					case 51:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -49:
						break;
					case 52:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -50:
						break;
					case 53:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -51:
						break;
					case 54:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -52:
						break;
					case 55:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -53:
						break;
					case 56:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -54:
						break;
					case 57:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -55:
						break;
					case 58:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -56:
						break;
					case 59:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -57:
						break;
					case 60:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -58:
						break;
					case 61:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -59:
						break;
					case 62:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -60:
						break;
					case 63:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -61:
						break;
					case 64:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -62:
						break;
					case 65:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -63:
						break;
					case 66:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -64:
						break;
					case 67:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -65:
						break;
					case 68:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -66:
						break;
					case 69:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -67:
						break;
					case 70:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -68:
						break;
					case 71:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -69:
						break;
					case 72:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -70:
						break;
					case 73:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -71:
						break;
					case 74:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -72:
						break;
					case 75:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -73:
						break;
					case 76:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -74:
						break;
					case 77:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -75:
						break;
					case 78:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -76:
						break;
					case 79:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -77:
						break;
					case 80:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -78:
						break;
					case 81:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -79:
						break;
					case 82:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -80:
						break;
					case 83:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -81:
						break;
					case 84:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -82:
						break;
					case 85:
						{ return new Token(Token.ID, yyline, yychar,
                        yychar+yytext().length()-1, yytext()); }
					case -83:
						break;
					default:
						yy_error(YY_E_INTERNAL,false);
					case -1:
					}
					yy_initial = true;
					yy_state = yy_state_dtrans[yy_lexical_state];
					yy_next_state = YY_NO_STATE;
					yy_last_accept_state = YY_NO_STATE;
					yy_mark_start();
					yy_this_accept = yy_acpt[yy_state];
					if (YY_NOT_ACCEPT != yy_this_accept) {
						yy_last_accept_state = yy_state;
						yy_mark_end();
					}
				}
			}
		}
	}
}
